@@ -110,10 +110,10 @@ class Step:
         self.taskID = lines[0]
         f.close()
 
-    # Storing the datahandoff in a dataframe and the converting  DF to json and printing it
-    # def handOff(self, rC, taskID, step, datatohandoff):
+    # Method to Handoff to the Nextstep 
     def handOff(self, dataToHandoff):
         try:
+            self.logInfo(self.step , self.taskExecutionID + " Handoff.")
             self.rC.publish(self.taskID + "_" + self.nextStep, dataToHandoff)
         except(ConnectionError) as cE:
             self.logError(self.nextStep, str(cE))
