@@ -5,6 +5,8 @@ from .destination_IPFS.client import IPFSDestination
 from .source_IPFS.client import IPFSSource
 from .source_mysql.client import MySQLSource
 from .destination_mysql.client import MySQLDestination
+from .destination_3TLIPFS.client import Destination3TLIPFS
+from .source_3TLIPFS.client import Source3TLIPFS
 from .source_postgres.client import PostgresSource
 from .destination_postgres.client import PostgresDestination
 
@@ -16,6 +18,8 @@ __all__ = [
     'IPFSSource',
     'MySQLSource',
     'MySQLDestination',
+    'Destination3TLIPFS',
+    'Source3TLIPFS',
     'PostgresDestination',
     'PostgresSource'
 
